@@ -1,36 +1,37 @@
 # -*- coding: utf-8 -*-
+from django.conf import settings
+from django.utils import importlib
+
 from django.db.models.fields import AutoField, CharField, TextField, SlugField
-from django.db.models.fields import DateField, DateTimeField, EmailField
+from django.db.models.fields import DateField, DateTimeField, TimeField, EmailField
 from django.db.models.fields import IntegerField, SmallIntegerField
-from django.db.models.fields import PositiveSmallIntegerField, PositiveIntegerField
+from django.db.models.fields import PositiveSmallIntegerField
+from django.db.models.fields import PositiveIntegerField
 from django.db.models.fields import FloatField, DecimalField
 from django.db.models.fields import BooleanField
 from django.db.models.fields import URLField
+from django.db.models  import FileField
+from django.db.models import get_model
 
 from django.contrib.contenttypes import generic
 from django.contrib.contenttypes.models import ContentType
 
-from django.contrib.contenttypes import generic
+from django.db.models import ForeignKey, ManyToManyField
 
 try:
     from django.db.models.fields import BigIntegerField
 except ImportError:
     BigIntegerField = IntegerField
 
-from django.db.models import ForeignKey, OneToOneField, ManyToManyField
-
-from string import letters
-from random import choice, randint
-from datetime import date
-from decimal import Decimal
 import generators
-import sys
 
+recipes = None
 
 #TODO: improve related models handling
 foreign_key_required = [lambda field: ('model', field.related.parent_model)]
 
 MAX_SELF_REFERENCE_LOOPS = 2
+MAX_MANY_QUANTITY = 5
 
 def make_one(model, **attrs):
     """
@@ -41,59 +42,85 @@ def make_one(model, **attrs):
     mommy = Mommy(model)
     return mommy.make_one(**attrs)
 
+
 def prepare_one(model, **attrs):
     """
-    Creates a BUT DOESN'T persist an instance from a given model its associated models.
+    Creates a BUT DOESN'T persist an instance from a given model its
+    associated models.
     It fill the fields with random values or you can specify
     which fields you want to define its values by yourself.
     """
     mommy = Mommy(model)
     return mommy.prepare(**attrs)
 
-def make_many(model, qty=5, **attrs):
+
+def make_many(model, quantity=None, **attrs):
+    quantity = quantity or MAX_MANY_QUANTITY
     mommy = Mommy(model)
-    return [mommy.make_one() for i in range(qty)]
+    return [mommy.make_one(**attrs) for i in range(quantity)]
+
+def _recipe(name):
+    app, recipe_name = name.split('.')
+    recipes = importlib.import_module('.'.join([app, 'mommy_recipes']))
+    return getattr(recipes, recipe_name)
+
+def make_recipe(mommy_recipe_name, **new_attrs):
+    return _recipe(mommy_recipe_name).make(**new_attrs)
+
+def prepare_recipe(mommy_recipe_name, **new_attrs):
+    return _recipe(mommy_recipe_name).prepare(**new_attrs)
 
 make_one.required = foreign_key_required
 prepare_one.required = foreign_key_required
 make_many.required = foreign_key_required
 
 default_mapping = {
-    BooleanField:generators.gen_boolean,
-    IntegerField:generators.gen_integer,
-    BigIntegerField:generators.gen_integer,
-    SmallIntegerField:generators.gen_integer,
+    BooleanField: generators.gen_boolean,
+    IntegerField: generators.gen_integer,
+    BigIntegerField: generators.gen_integer,
+    SmallIntegerField: generators.gen_integer,
 
-    PositiveIntegerField:lambda: generators.gen_integer(0),
-    PositiveSmallIntegerField:lambda: generators.gen_integer(0),
+    PositiveIntegerField: lambda: generators.gen_integer(0),
+    PositiveSmallIntegerField: lambda: generators.gen_integer(0),
 
-    FloatField:generators.gen_float,
-    DecimalField:generators.gen_decimal,
+    FloatField: generators.gen_float,
+    DecimalField: generators.gen_decimal,
 
-    CharField:generators.gen_string,
-    TextField:generators.gen_text,
-    SlugField:generators.gen_slug,
+    CharField: generators.gen_string,
+    TextField: generators.gen_text,
+    SlugField: generators.gen_slug,
 
-    ForeignKey:make_one,
-    #OneToOneField:make_one,
-    ManyToManyField:make_many,
+    ForeignKey: make_one,
+    #OneToOneField: make_one,
+    ManyToManyField: make_many,
 
-    DateField:generators.gen_date,
-    DateTimeField:generators.gen_date,
+    DateField: generators.gen_date,
+    DateTimeField: generators.gen_datetime,
+    TimeField: generators.gen_time,
 
-    URLField:generators.gen_url,
-    EmailField:generators.gen_email,
+    URLField: generators.gen_url,
+    EmailField: generators.gen_email,
+    FileField: generators.gen_file_field,
 
-    ContentType:generators.gen_content_type,
+    ContentType: generators.gen_content_type,
 }
 
+class ModelNotFound(Exception):
+    pass
+
 class Mommy(object):
     attr_mapping = {}
     type_mapping = None
 
     def __init__(self, model):
         self.type_mapping = default_mapping.copy()
-        self.model = model
+        if isinstance(model, str):
+            app_label, model_name = model.split('.')
+            self.model = get_model(app_label, model_name)
+            if not self.model:
+                raise ModelNotFound("could not find model '%s' in the app '%s'." %(model_name, app_label))
+        else:
+            self.model = model
 
     def make_one(self, **attrs):
         '''Creates and persists an instance of the model
@@ -108,7 +135,7 @@ class Mommy(object):
         return self._make_one(commit=False, **attrs)
 
     def get_fields(self):
-        return self.model._meta.fields+self.model._meta.many_to_many
+        return self.model._meta.fields + self.model._meta.many_to_many
 
     #Method too big
     def _make_one(self, commit=True, **attrs):
@@ -120,8 +147,8 @@ class Mommy(object):
             if isinstance(field, (AutoField, generic.GenericRelation)):
                 continue
 
-            # If not specified, django automatically sets blank=True and default
-            # on BooleanFields so we don't need to check these
+            # If not specified, django automatically sets blank=True and
+            # default on BooleanFields so we don't need to check these
             if not isinstance(field, BooleanField):
                 if field.has_default() or field.blank:
                     continue
@@ -141,7 +168,6 @@ class Mommy(object):
                 else:
                     attrs[field.name] = self.generate_value(field)
 
-
         instance = self.model(**attrs)
 
         # m2m only works for persisted instances
@@ -157,15 +183,18 @@ class Mommy(object):
         return instance
 
     def generate_value(self, field):
-        '''Calls the generator associated with a field passing all required args.
+        '''
+        Calls the generator associated with a field passing all required args.
 
         Generator Resolution Precedence Order:
         -- attr_mapping - mapping per attribute name
         -- choices -- mapping from avaiable field choices
         -- type_mapping - mapping from user defined type associated generators
-        -- default_mapping - mapping from pre-defined type associated generators
+        -- default_mapping - mapping from pre-defined type associated
+           generators
 
-        `attr_mapping` and `type_mapping` can be defined easely overwriting the model.
+        `attr_mapping` and `type_mapping` can be defined easely overwriting the
+        model.
         '''
 
         if field.name in self.attr_mapping:
@@ -179,10 +208,12 @@ class Mommy(object):
         else:
             raise TypeError('%s is not supported by mommy.' % field.__class__)
 
-        # attributes like max_length, decimal_places are take in account when generating the value.
+        # attributes like max_length, decimal_places are take in account when
+        # generating the value.
         required_field_attrs = get_required_values(generator, field)
         return generator(**required_field_attrs)
 
+
 def get_required_values(generator, field):
     '''
     Gets required values for a generator from the field.
@@ -195,7 +226,7 @@ def get_required_values(generator, field):
     if hasattr(generator, 'required'):
         for item in generator.required:
 
-            if callable(item): # mommy can deal with the nasty hacking too!
+            if callable(item):  # mommy can deal with the nasty hacking too!
                 key, value = item(field)
                 rt[key] = value
 
@@ -203,6 +234,7 @@ def get_required_values(generator, field):
                 rt[item] = getattr(field, item)
 
             else:
-                raise ValueError("Required value '%s' is of wrong type. Don't make mommy sad." % str(item))
+                raise ValueError("Required value '%s' is of wrong type. \
+                                  Don't make mommy sad." % str(item))
 
     return rt
